.. nc-time-axis documentation master file, created by
   sphinx-quickstart on Tue Aug 17 14:53:26 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

nc-time-axis
============

**nc-time-axis** is a package that enables making plots in matplotlib with axes made
up of :py:class:`cftime.datetime` dates with any calendar type.  

.. toctree::
   :caption: Getting started
   :maxdepth: 1

   installation
   examples

.. toctree::
   :caption: Reference
   :maxdepth: 1

   release-notes
   api

.. toctree::
   :caption: Maintenance
   :maxdepth: 1

   releases
